package com.energy.manage.service.mappers.autoanalysisconfigdetail;

import com.energy.manage.common.mapper.MyMapper;
import com.energy.manage.common.po.autoanalysisconfigdetail.AutoAnalysisConfigDetailPo;
import com.energy.manage.service.domain.dto.analysis.AutoAnalysisConfigDetailDto;
import com.energy.manage.service.domain.vo.analysis.AutoAnalysisConfigDetailVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface AutoAnalysisConfigDetailMapper extends MyMapper<AutoAnalysisConfigDetailPo> {

    /**
     * 根据条件查询配置
     * @param detail
     * @return
     */
    List<AutoAnalysisConfigDetailVo> selectByCondition(AutoAnalysisConfigDetailDto detail);

    /**
     * 插入配置
     * @param detailDto
     * @return
     */
    int insertConfig(AutoAnalysisConfigDetailDto detailDto);

    /**
     * 根据条件更新配置
     * @param detailDto
     * @return
     */
    int updateConfigByCondition(AutoAnalysisConfigDetailDto detailDto);

    /**
     * 根据唯一id查询配置
     * @param configUniqueId
     * @return
     */
    AutoAnalysisConfigDetailPo selectByUniqueId(@Param("configUniqueId") String configUniqueId);

    /**
     * 查询配置是否存在
     * @param detailDto
     * @return
     */
    int selectExistConfig(AutoAnalysisConfigDetailDto detailDto);
}
